﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Security.Cryptography;
using System.Text;
using System.Web;
using System.Net.Mail;
using System.Web.UI;
using System.Web.UI.WebControls;
public partial class paytr_link_api_callback : System.Web.UI.Page
{
    // ####################### REQUIRED FIELDS TO BE REGULATED #######################
    //
    // API - Information Integration  - You can get them from the information page after logging into the PayTR Merchant Panel.
    string merchant_key     = "XXXXXXXXXXXXXXXX";
    string merchant_salt    = "XXXXXXXXXXXXXXXX";
    // ###########################################################################

    protected void Page_Load(object sender, EventArgs e)
    {
        // ####### You do not need to make any changes in this part. #######
        // 
        // Hashing with POST values.
        string callback_id = Request.Form["callback_id"];
        string merchant_oid = Request.Form["merchant_oid"];
        string status = Request.Form["status"];
        string total_amount = Request.Form["total_amount"];
        string hash = Request.Form["hash"];

        string Birlestir = string.Concat(callback_id, merchant_oid, merchant_salt, status, total_amount);
        HMACSHA256 hmac = new HMACSHA256(Encoding.UTF8.GetBytes(merchant_key));
        byte[] b = hmac.ComputeHash(Encoding.UTF8.GetBytes(Birlestir));
        string token = Convert.ToBase64String(b);

        //
        // Checking whether the hash value in POST matches the hash value that will be generated using the values in POST is very important for security reasons. 
        // This is necessary to ensure that the POST request comes from the PayTR system and the values do not change during request.  If you do not check hash value, you may face financial losses..
        if (hash.ToString() != token)
        {
            Response.Write("PAYTR notification failed: bad hash");
            return;
        }

        ////////////////////////////////////////////////////////////////////////////////////////////
        //
        //
        ////////////////////////////// Returned values in POST //////////////////////////////
        // [hash]            => The hash information to be used for verification.
        // [merchant_oid]    => Order reference number generated by PayTR.
        // [status]          => If the payment is successful, it gets value as success. (In Link API, there is no callback for unsuccessful payments).
        // [total_amount]    => Total payment amount (For example, if the payment is made in installments, the amount will be different from payment_amount.)
        // [payment_amount]  => It is the "payment_amount" value that you send in the 1st step.
        // [payment_type]    => This value indicates which payment method the customer used to pay. (  card, bex etc. )
        // [currency]        => It indicates which currency is used for payment. (‘TL’, ‘USD’, ‘EUR’, ‘GBP’, ‘RUB’)
        // [callback_id]     => Callback_id from create service
        // [merchant_id]     => PayTR merchant number.
        // [test_mode]       => If your merchant is in test mode, it returns as 1.
        ////////////////////////////////////////////////////////////////////////////////////////////
        //

        // Here are what needs to be done.
        // 1) Check the payment status from your database using ['callback_id'].
        // 2) If the payment has already been confirmed (you received the callback) end the flow by sending just echo "OK";

        /* Example for payment status query 
        status = SQL
        if(status == "confirm"){
             Response.Write("OK");
         }
        */

        if (status == "success")
        { //Here are what needs to be done.

            // If the payment is successful, you should take action in this area.
            // 1) Confirm the payment in your database.
            // 2) If you are going to inform your customer such as message / SMS / e-mail, you can do that at this part. You can access the data by saving the merchant_oid information and querying it at this part.
            // 3) ['total_amount'] is the total amount of the customer payment. You must use this amount in your accounting transactions.
        }
        else
        { //Payment is not Confirmed

            // Here are what needs to be done.
            // 1) There is no callback for unsuccessful payments in the Link API.
            // 2) So there will be no access here in the code stream. However, if you wish, you can write a handler here for future improvements to the Link API.
            //['failed_reason_msg'] - failed error message
        }
        // Notify the PayTR system that the notification has been received. Do not remove the OK answer from this field.
        Response.Write("OK");
    }
}